==> xreact-2.6.3.tgz: package/README.md <==
# xReact

xReact is a Functional Reactive State Wrapper for React Components. Data flow in xReact is observable and unidirectional.

> formerly know as react-most, renamed so because mostjs is not madatory anymore.

[![CircleCI](https://img.shields.io/circleci/project/github/reactive-react/xreact/master.svg)](https://circleci.com/gh/reactive-react/xreact)
[![Join the chat at https://gitter.im/jcouyang/react-most](https://badges.gitter.im/jcouyang/react-most.svg)](https://gitter.im/jcouyang/react-most?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
[![](https://img.shields.io/github/stars/reactive-react/xreact.svg?label=Star)](https://github.com/reactive-react/xreact)
[![codecov](https://codecov.io/gh/reactive-react/xreact/branch/master/graph/badge.svg)](https://codecov.io/gh/reactive-react/xreact)
[![npm](https://img.shields.io/npm/v/xreact.svg)](https://www.npmjs.com/package/xreact)
[![greenkeeper.io](https://badges.greenkeeper.io/reactive-react/xreact.svg)](https://greenkeeper.io)

![](https://www.evernote.com/l/ABet-_q4zTxGQrpnD0lwf_An5z9FvAQOvNEB/image.png)

## [Get Started](https://xreact.oyanglul.us)

xReact works for both TypeScript and CMD JS, to install xReact simply use yarn or npm:

```
npm install xreact --save
# or
yarn add xreact
```


- Come from redux? :point_right: <https://xreact.oyanglul.us/Get-Started.html>
- Come from fantasy land? :rainbow: <https://xreact.oyanglul.us/Fantasy.html>
- Examples :point_down:
  - <https://github.com/reactive-react/xreact/tree/master/examples>
  - <https://xreact.oyanglul.us/Examples.html>

## Documentation

All xReact information and documentation is available on [the website](http://xreact.oyanglul.us/).

And... we have a list of [frequently-asked questions](https://xreact.oyanglul.us/FAQ.html).

Our goal is to have clear and comprehensive documentation. If you notice problems, omissions, or errors, please [let us know](https://github.com/reactive-react/xreact/issues), or PR is more than welcome.

==> xreact-5.0.1.tgz: package/README.md <==
# xReact

xReact is a Functional Reactive State Wrapper for React Components. Data flow in xReact is observable and unidirectional.

> formerly know as react-most, renamed so because mostjs is not madatory anymore.

[![CircleCI](https://img.shields.io/circleci/project/github/reactive-react/xreact/master.svg)](https://circleci.com/gh/reactive-react/xreact)
[![Join the chat at https://gitter.im/jcouyang/react-most](https://badges.gitter.im/jcouyang/react-most.svg)](https://gitter.im/jcouyang/react-most?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
[![](https://img.shields.io/github/stars/reactive-react/xreact.svg?label=Star)](https://github.com/reactive-react/xreact)
[![codecov](https://codecov.io/gh/reactive-react/xreact/branch/master/graph/badge.svg)](https://codecov.io/gh/reactive-react/xreact)
[![npm](https://img.shields.io/npm/v/xreact.svg)](https://www.npmjs.com/package/xreact)
[![greenkeeper.io](https://badges.greenkeeper.io/reactive-react/xreact.svg)](https://greenkeeper.io)

![](https://www.evernote.com/l/ABet-_q4zTxGQrpnD0lwf_An5z9FvAQOvNEB/image.png)

## [Get Started](https://xreact.oyanglul.us)

xReact works for both TypeScript and CMD JS, to install xReact simply use yarn or npm:

```
npm install xreact --save
# or
yarn add xreact
```


- Come from redux? :point_right: <https://xreact.oyanglul.us/Get-Started.html>
- Come from fantasy land? :rainbow: <https://xreact.oyanglul.us/examples/fantasy.html>

## Documentation

All xReact information and documentation is available on [the website](http://xreact.oyanglul.us/).

And... we have a list of [frequently-asked questions](https://xreact.oyanglul.us/FAQ.html).

Our goal is to have clear and comprehensive documentation. If you notice problems, omissions, or errors, please [let us know](https://github.com/reactive-react/xreact/issues), or PR is more than welcome.
